import 'dart:core';
import 'package:latlong2/latlong.dart';
import 'package:flutter/material.dart';

class Measurement {
  int measurementID;
  DateTime timeMeasured;
  Sensor sensor;
  String bodyOfWater;
  LatLng center;
  List <SubDiv> subDivs;

  Measurement({
    required this.measurementID,
    required this.timeMeasured,
    required this.sensor,
    required this.bodyOfWater,
    required this.center,
    required this.subDivs,
  });

  factory Measurement.fromJson(Map<String, dynamic> json) {
    return Measurement(
        measurementID: json['MeasurementID'],
        timeMeasured: DateTime.parse(json['TimeMeasured']),
        sensor: Sensor.fromJson(json['Sensor']),
        bodyOfWater: json['BodyOfWater'] ?? 'nil',
        center: LatLng(json['CenterLat'], json['CenterLon']),
        subDivs: (json['Subdivisions'] as List<dynamic>).map((data) => SubDiv.fromJson(data)).toList(),
    );
  }
}

class SubDiv {
  String sub_div_id;
  int groupID;
  double minThickness;
  double avgThickness;
  LatLng center;
  double accuracy;
  Color color;
  Color savedColor;

  SubDiv({
    required this.sub_div_id,
    required this.groupID,
    required this.minThickness,
    required this.avgThickness,
    required this.center,
    required this.accuracy,
    required this.color,
    required this.savedColor
  });

  factory SubDiv.fromJson(Map<String, dynamic> json) {
    return SubDiv(
      sub_div_id: json['SubdivID'].toString(),
      groupID: json['GroupID'],
      minThickness: json['MinThickness'],
      avgThickness: json['AvgThickness'],
      center: LatLng(json['CenLatitude'], json['CenLongitude']),
      accuracy: json['Accuracy'],
      // Set grey as default color
      color: json['Color'] != null ? Color(json['Color']) : Colors.grey,
      savedColor: json['Color'] != null ? Color(json['Color']) : Colors.grey,
    );
  }
}

class Sensor {
  int sensorID;
  String sensorType;
  bool active;

  Sensor({
    required this.sensorID,
    required this.sensorType,
    required this.active,
  });

  factory Sensor.fromJson(Map<String, dynamic> json) {
    return Sensor(
      sensorID: json['SensorID'],
      sensorType: json['SensorType'] ?? 'nil',
      active: json['Active'],
    );
  }
}
