import 'dart:async';
import 'package:app/server_requests/fetch_relation.dart';
import 'package:flutter/material.dart';

import '../consts.dart';
import '../data_classes.dart';
import '../widgets/main_layout.dart';
import '../utils/custom_search_delegate.dart';
import '../server_requests/fetch_relation.dart';
import '../server_requests/fetch_markers.dart';

class DefaultPage extends StatefulWidget {
  const DefaultPage({Key? key}) : super(key: key);

  @override
  _DefaultPageState createState() => _DefaultPageState();
}

class _DefaultPageState extends State<DefaultPage> {
  late Timer _timer;
  bool serverConnection = true;
  bool dialogShown = false;

  @override
  void dispose() {
    _timer.cancel();
    super.dispose();
  }

  /// Display message to user
  void showConnectionMessage() {
    showDialog(
      context: context,
      builder: (context) => AlertDialog(
        actions: [
          TextButton(
            onPressed: () {
              Navigator.of(context).pop();
              },
            child: const Text("Ok"),
          )
        ],
        title: const Center(
          child: Text("No server connection")
        ),
        contentPadding: const EdgeInsets.all(10.0),
        content: const Text(
          "The app may display outdated information. Use with caution!",
          textAlign: TextAlign.center, // Align text center
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          backgroundColor: Colors.black87,
          leading: IconButton(
            icon: const Icon(
                Icons.menu,
                color: Colors.white54
            ),
            onPressed: () {
              // Not implemented
            },
          ),
          title: Text(
            selectedLake, // Display name of current map
            style: regTextStyleBig,
          ),
          actions: [
            IconButton(
              icon: const Icon(
                  Icons.search,
                  color: Colors.white54
              ),
              onPressed: () {
                showSearch( // Fetch new relation and measurements on search
                  context: context,
                  delegate: CustomSearchDelegate((String result) {
                    setState(() async {
                      selectedRelation = await fetchRelation();
                      selectedMarkerList = await fetchMeasurements().then((fetchResult) {
                        List<Measurement> measurements = fetchResult.measurements;
                        serverConnection = fetchResult.connected;

                        // Return the measurements
                        return measurements;
                      }).catchError((error) {
                        serverConnection = false;
                        throw Exception("Failed to fetch measurements: $error");
                      });
                      selectedLake = result;
                    });
                  }),
                );
              },
            ),
          ],
        ),
        body: Container( // Return container with list view and background color
          color: const Color(0xff151515),
          child: ListView(
            children: [
              MapContainerWidget(
                markerList: selectedMarkerList,
                relation: selectedRelation,
                serverConnection: serverConnection,
              ),
            ],
          ),
        ),
      ),
    );
  }
}