import 'dart:async';
import 'dart:typed_data';
import 'package:app/consts.dart';

import '../data_classes.dart';
import '../server_requests/fetch_markers.dart';
import '../server_requests/fetch_relation.dart';

Future<void> initialiseState() async{
  bool serverConnection = true;

  late Future<List<Measurement>> markerListFuture;
  late Future<Uint8List> relationFuture;

  // Try to fetch measurement data from server
  markerListFuture = fetchMeasurements().then((fetchResult) {
    List<Measurement> measurements = fetchResult.measurements;
    serverConnection = fetchResult.connected;

    // Return the measurements
    return measurements;
  }).catchError((error) {
    serverConnection = false;
    throw Exception("Failed to fetch measurements: $error");
  });

  // Attempt to fetch relation from server if app establishes connection
  if (serverConnection) {
    relationFuture = fetchRelation();
  } else { // Read last saved data
    relationFuture = loadSavedRelation();
  }

  selectedRelation = await relationFuture;
  selectedMarkerList = await markerListFuture;
}